4.43. umbra.ui.languages — Umbra 1.0.9 documentation

# 4.43. umbra.ui.languages

languages.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines languages manipulation related objects.

Others:

## 4.43.1. Module Attributes

`umbra.ui.languages.` `LOGGER`

`umbra.ui.languages.` `PYTHON_GRAMMAR_FILE`

`umbra.ui.languages.` `LOGGING_GRAMMAR_FILE`

`umbra.ui.languages.` `TEXT_GRAMMAR_FILE`

`umbra.ui.languages.` `LANGUAGES_ACCELERATORS`

`umbra.ui.languages.` `DEFAULT_INDENT_MARKER`

`umbra.ui.languages.` `PYTHON_LANGUAGE`

`umbra.ui.languages.` `LOGGING_LANGUAGE`

`umbra.ui.languages.` `TEXT_LANGUAGE`

## 4.43.2. Functions

`umbra.ui.languages.` `getObjectFromLanguageAccelerators`(accelerator)

  Returns the object associated to given accelerator.

  Parameters: | accelerator (unicode) – Accelerator.
  Returns: | Object.
  Return type: | object

`umbra.ui.languages.` `getLanguageDescription`(grammarfile)

  Gets the language description from given language grammar file.

  Parameters: | grammarfile (unicode) – Language grammar.
  Returns: | Language description.
  Return type: | Language

`umbra.ui.languages.` `getPythonLanguage`()

  Returns the Python language description.

  Returns: | Python language description.
  Return type: | Language

`umbra.ui.languages.` `getLoggingLanguage`()

  Returns the Logging language description.

  Returns: | Logging language description.
  Return type: | Language

`umbra.ui.languages.` `getTextLanguage`()

  Returns the Text language description.

  Returns: | Text language description.
  Return type: | Language

## 4.43.3. Classes

class `umbra.ui.languages.` `Language`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  Defines a storage object for the `Editor` class language description.

  Initializes the class.

  Parameters: | **kwargs – name, file, parser, extensions, highlighter, completer, preInputAccelerators, postInputAccelerators, visualAccelerators, indentMarker, commentMarker, commentBlockMarkerStart, commentBlockMarkerEnd, symbolsPairs, indentationSymbols, rules, tokens, theme. ( Key / Value pairs )